Welcome to PlasmaCalcs's documentation!
=======================================

**PlasmaCalcs** provides a consistent interface (in Python) for plasma calculations from any inputs.

See also `PlasmaCalcs on pypi <https://pypi.org/project/plasmacalcs/>`_ (install via ``pip install plasmacalcs``)

You can also find the latest version here: ``https://gitlab.com/Sevans7/plasmacalcs``


.. note::

   This project is still under active development. This note was last updated on March 30, 2025.

Contents
--------

For API details, it's easier to navigate via the sidebar on the left. Below is a comprehensive table of contents.


.. toctree::

   usage
   api
